# AI Hero Python SDK
1. Log into [https://app.aihero.studio] and create a project.


2. Install AI Hero using pip
```                
pip install aihero
```
                
3. In your code, import aihero and get this project.
```                
from aihero import Project
project = Project(project_id="YOUR PROJECT ID", api_key="YOUR API KEY")
```
                
Start using any of our tools